LineViewport

Struct LineViewport 

pub struct LineViewport { /* private fields */ }
The buffer line viewport in a buffer.

Implementations

Source

impl LineViewport

pub fn new( rows: LiteMap<u16, RowViewport>, start_filled_cols: usize, end_filled_cols: usize, ) -> Self

Make new instance.

pub fn rows(&self) -> &LiteMap<u16, RowViewport>

Maps row_idx (in the window) => its row-wise viewport. The row index starts from 0.

pub fn start_filled_cols(&self) -> usize

Get extra filled columns at the beginning of the line.

For most cases, this value should be zero. But when the first char (indicate by start_char_idx) doesn’t show at the first column of the row, and meanwhile the cells width is not enough for the previous character.

For example:

             Column index in viewport -> 0   4
                                         |   |
0         10        20        30    36   |   37  <- Char index in the buffer
|         |         |         |     |    |   |
                                        |---------------------|
This is the beginning of the buffer.<--H|T-->But it begins to |show at here.
The second line is really short!        |                     |
Too short to show in viewport, luckily t|he third line is ok. |
                                        |---------------------|

The example shows the first char B starts at column index 4 in the viewport, and its previous char <--HT--> uses 8 cells width so cannot fully shows in the viewport.

In this case, the variable start_filled_cols is 4, the start char index is 37.

pub fn end_filled_cols(&self) -> usize

Get extra filled columns at the end of the row.